==> ckan-2.1.1.tar.gz: ckan-2.1.1/ckan/public/base/i18n/da_DK.js <==
{
  "": {
    "domain": "ckan",
    "lang": "da_DK",
    "plural-forms": "nplurals=2; plural=(n != 1);"
  },
  "An Error Occurred": [
    null,
    "Der opstod en fejl"
  ],
  "Are you sure you want to perform this action?": [
    null,
    "Er du sikker på, at du vil udføre denne handling?"
  ],
  "Cancel": [
    null,
    "Annullér"
  ],
  "Confirm": [
    null,
    "Bekræft"
  ],
  "Edit": [
    null,
    "Redigér"
  ],
  "Failed to load data API information": [
    null,
    "Kunne ikke indlæse data-API-information"
  ],
  "Follow": [
    null,
    "Følg"
  ],
  "Hide": [
    null,
    "Skjul"
  ],
  "Input is too short, must be at least one character": [
    null,
    "Input er for kort, skal være mindst én karakter"
  ],
  "Loading...": [
    null,
    "Loading..."
  ],
  "No matches found": [
    null,
    "Ingen resultater fundet"
  ],
  "Please Confirm Action": [
    null,
    "Bekræft venligst handling"
  ],
  "Resource uploaded": [
    null,
    "Ressource uploadet"
  ],
  "Show more": [
    null,
    "Vis mere"
  ],
  "Start typing…": [
    null,
    "Begynd indtastning..."
  ],
  "There are unsaved modifications to this form": [
    null,
    "Der er ændringer til denne formular som ikke er gemt"
  ],
  "There is no API data to load for this resource": [
    null,
    "Der er ingen API-data at indlæse for denne ressource"
  ],
  "URL": [
    null,
    "URL"
  ],
  "Unable to authenticate upload": [
    null,
    "Ude af stand til at autentificere upload"
  ],
  "Unable to get data for uploaded file": [
    null,
    "Ude af stand til at hente data for uploadet fil"
  ],
  "Unable to upload file": [
    null,
    "Ude af stand til at uploade fil"
  ],
  "Unfollow": [
    null,
    "Følg ikke"
  ],
  "Upload a file": [
    null,
    "Upload en fil"
  ],
  "You are uploading a file. Are you sure you want to navigate away and stop this upload?": [
    null,
    "Du uploader en fil. Er du sikker på, du vil navigere væk og standse upload?"
  ],
  "show less": [
    null,
    "vis færre"
  ],
  "show more": [
    null,
    "vis flere"
  ]
}

==> ckan-2.2.1.tar.gz: ckan-2.2.1/ckan/public/base/i18n/da_DK.js <==
{
  "": {
    "domain": "ckan",
    "lang": "da_DK",
    "plural-forms": "nplurals=2; plural=(n != 1);"
  },
  "An Error Occurred": [
    null,
    "Der opstod en fejl"
  ],
  "Are you sure you want to perform this action?": [
    null,
    "Er du sikker på, at du vil udføre denne handling?"
  ],
  "Cancel": [
    null,
    "Annullér"
  ],
  "Confirm": [
    null,
    "Bekræft"
  ],
  "Edit": [
    null,
    "Redigér"
  ],
  "Failed to load data API information": [
    null,
    "Kunne ikke indlæse data-API-information"
  ],
  "Follow": [
    null,
    "Følg"
  ],
  "Hide": [
    null,
    "Skjul"
  ],
  "Image": [
    null,
    "Billede"
  ],
  "Input is too short, must be at least one character": [
    null,
    "Input er for kort, skal være mindst én karakter"
  ],
  "Link": [
    null,
    "Link"
  ],
  "Link to a URL on the internet (you can also link to an API)": [
    null,
    "Link til en URL på internettet (du kan også linke til et API)"
  ],
  "Loading...": [
    null,
    "Loading..."
  ],
  "No matches found": [
    null,
    "Ingen resultater fundet"
  ],
  "Please Confirm Action": [
    null,
    "Bekræft venligst handling"
  ],
  "Remove": [
    null,
    "Fjern"
  ],
  "Reorder resources": [
    null,
    "Skift rækkefølge på ressourcer"
  ],
  "Reset this": [
    null,
    "Nulstil dette"
  ],
  "Resource uploaded": [
    null,
    "Ressource uploadet"
  ],
  "Save order": [
    null,
    "Gem rækkefølge"
  ],
  "Saving...": [
    null,
    "Gemmer..."
  ],
  "Show more": [
    null,
    "Vis mere"
  ],
  "Start typing…": [
    null,
    "Begynd indtastning..."
  ],
  "There are unsaved modifications to this form": [
    null,
    "Der er ændringer til denne formular som ikke er gemt"
  ],
  "There is no API data to load for this resource": [
    null,
    "Der er ingen API-data at indlæse for denne ressource"
  ],
  "URL": [
    null,
    "URL"
  ],
  "Unable to authenticate upload": [
    null,
    "Ude af stand til at autentificere upload"
  ],
  "Unable to get data for uploaded file": [
    null,
    "Ude af stand til at hente data for uploadet fil"
  ],
  "Unable to upload file": [
    null,
    "Ude af stand til at uploade fil"
  ],
  "Unfollow": [
    null,
    "Følg ikke"
  ],
  "Upload": [
    null,
    "Upload"
  ],
  "Upload a file": [
    null,
    "Upload en fil"
  ],
  "Upload a file on your computer": [
    null,
    "Upload en fil fra din computer"
  ],
  "You are uploading a file. Are you sure you want to navigate away and stop this upload?": [
    null,
    "Du uploader en fil. Er du sikker på, du vil navigere væk og standse upload?"
  ],
  "show less": [
    null,
    "vis færre"
  ],
  "show more": [
    null,
    "vis flere"
  ]
}
